<?php
/**
 * Plugin Name: CargoHub - WooCommerce Courier Service
 * Plugin URI: https://cargohub.wphacks4u.com
 * Description: A custom WooCommerce extension for courier services with weight-based pricing, volumetric dimensions, service types, and COD options.
 * Version: 1.0.0
 * Author: Muhammed Hashim
 * Author URI: https://wphacks4u.com/
 * Text Domain: cargohub
 * Domain Path: /languages
 * Requires at least: 5.0
 * Requires PHP: 7.2
 * WC requires at least: 4.0
 * WC tested up to: 8.0
 *
 * @package CargoHub
 */

// If this file is called directly, abort.
if (!defined('WPINC')) {
    die;
}

// Define plugin constants
define('CARGOHUB_VERSION', '1.0.0');
define('CARGOHUB_PLUGIN_DIR', plugin_dir_path(__FILE__));
define('CARGOHUB_PLUGIN_URL', plugin_dir_url(__FILE__));
define('CARGOHUB_PLUGIN_BASENAME', plugin_basename(__FILE__));

/**
 * Check if WooCommerce is active
 */
function cargohub_check_woocommerce_active() {
    if (!in_array('woocommerce/woocommerce.php', apply_filters('active_plugins', get_option('active_plugins')))) {
        add_action('admin_notices', 'cargohub_woocommerce_missing_notice');
        return false;
    }
    return true;
}

/**
 * Display notice if WooCommerce is not active
 */
function cargohub_woocommerce_missing_notice() {
    ?>
    <div class="error">
        <p><?php esc_html_e('CargoHub requires WooCommerce to be installed and active. You can download', 'cargohub'); ?> 
        <a href="https://woocommerce.com/" target="_blank">WooCommerce</a> 
        <?php esc_html_e('here.', 'cargohub'); ?></p>
    </div>
    <?php
}

/**
 * The code that runs during plugin activation.
 */
function activate_cargohub() {
    // Check if WooCommerce is active
    if (!cargohub_check_woocommerce_active()) {
        deactivate_plugins(plugin_basename(__FILE__));
        wp_die(esc_html__('Please install and activate WooCommerce before activating CargoHub.', 'cargohub'));
        return;
    }

    // Create necessary database tables and default settings if needed
    require_once CARGOHUB_PLUGIN_DIR . 'includes/class-cargohub-activator.php';
    CargoHub_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 */
function deactivate_cargohub() {
    require_once CARGOHUB_PLUGIN_DIR . 'includes/class-cargohub-deactivator.php';
    CargoHub_Deactivator::deactivate();
}

register_activation_hook(__FILE__, 'activate_cargohub');
register_deactivation_hook(__FILE__, 'deactivate_cargohub');

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require CARGOHUB_PLUGIN_DIR . 'includes/class-cargohub.php';

/**
 * Begins execution of the plugin.
 */
function run_cargohub() {
    // Check if WooCommerce is active before running the plugin
    if (cargohub_check_woocommerce_active()) {
        $plugin = new CargoHub();
        $plugin->run();
    }
}
add_action('plugins_loaded', 'run_cargohub');