<?php
/**
 * Admin View: Dashboard
 *
 * @package CargoHub
 */

// Exit if accessed directly.
if (!defined('WPINC')) {
    exit;
}

// Get current stats
global $wpdb;

// Get total courier orders
$total_orders = $wpdb->get_var("
    SELECT COUNT(*)
    FROM {$wpdb->prefix}postmeta pm
    JOIN {$wpdb->prefix}posts p ON p.ID = pm.post_id
    WHERE pm.meta_key = '_cargohub_service_type'
    AND pm.meta_value != ''
    AND p.post_type = 'shop_order'
");

// Get orders by service type
$service_type_orders = $wpdb->get_results("
    SELECT pm.meta_value as service_type, COUNT(*) as count
    FROM {$wpdb->prefix}postmeta pm
    JOIN {$wpdb->prefix}posts p ON p.ID = pm.post_id
    WHERE pm.meta_key = '_cargohub_service_type'
    AND pm.meta_value != ''
    AND p.post_type = 'shop_order'
    GROUP BY pm.meta_value
");

// Get COD orders
$cod_orders = $wpdb->get_var("
    SELECT COUNT(*)
    FROM {$wpdb->prefix}postmeta pm
    JOIN {$wpdb->prefix}posts p ON p.ID = pm.post_id
    WHERE pm.meta_key = '_cargohub_cod_option'
    AND pm.meta_value = 'yes'
    AND p.post_type = 'shop_order'
");

// Get service type information
$service_types = $wpdb->get_results("
    SELECT service_code, service_name
    FROM {$wpdb->prefix}cargohub_service_types
    WHERE active = 1
");

// Service type lookup
$service_type_lookup = array();
foreach ($service_types as $service_type) {
    $service_type_lookup[$service_type->service_code] = $service_type->service_name;
}

// Get recent courier orders
$recent_orders = $wpdb->get_results("
    SELECT p.ID as order_id, p.post_date, pm.meta_value as service_type
    FROM {$wpdb->prefix}postmeta pm
    JOIN {$wpdb->prefix}posts p ON p.ID = pm.post_id
    WHERE pm.meta_key = '_cargohub_service_type'
    AND pm.meta_value != ''
    AND p.post_type = 'shop_order'
    ORDER BY p.post_date DESC
    LIMIT 5
");

?>
<div class="wrap cargohub-dashboard">
    <h1><?php esc_html_e('CargoHub Dashboard', 'cargohub'); ?></h1>
    
    <div class="cargohub-welcome-panel">
        <div class="cargohub-welcome-panel-content">
            <h2><?php esc_html_e('Welcome to CargoHub!', 'cargohub'); ?></h2>
            <p class="about-description"><?php esc_html_e('CargoHub is a courier service management plugin for WooCommerce that helps you handle weight-based pricing, dimensions, and COD options.', 'cargohub'); ?></p>
            <div class="cargohub-welcome-panel-column-container">
                <div class="cargohub-welcome-panel-column">
                    <h3><?php esc_html_e('Get Started', 'cargohub'); ?></h3>
                    <ul>
                        <li><a href="<?php echo esc_url(admin_url('admin.php?page=cargohub-settings')); ?>" class="button button-primary"><?php esc_html_e('Configure Settings', 'cargohub'); ?></a></li>
                        <li><a href="<?php echo esc_url(admin_url('admin.php?page=cargohub-service-types')); ?>"><?php esc_html_e('Manage Service Types', 'cargohub'); ?></a></li>
                        <li><a href="<?php echo esc_url(admin_url('admin.php?page=cargohub-zones')); ?>"><?php esc_html_e('Configure Shipping Zones', 'cargohub'); ?></a></li>
                        <li><a href="<?php echo esc_url(admin_url('admin.php?page=cargohub-rates')); ?>"><?php esc_html_e('Set Up Shipping Rates', 'cargohub'); ?></a></li>
                    </ul>
                </div>
                <div class="cargohub-welcome-panel-column">
                    <h3><?php esc_html_e('Next Steps', 'cargohub'); ?></h3>
                    <ul>
                        <li><?php esc_html_e('Create courier products in WooCommerce', 'cargohub'); ?></li>
                        <li><?php esc_html_e('Test the checkout process', 'cargohub'); ?></li>
                        <li><?php esc_html_e('Configure email templates', 'cargohub'); ?></li>
                        <li><?php esc_html_e('Review order processing workflow', 'cargohub'); ?></li>
                    </ul>
                </div>
                <div class="cargohub-welcome-panel-column cargohub-welcome-panel-last">
                    <h3><?php esc_html_e('More Actions', 'cargohub'); ?></h3>
                    <ul>
                        <li><a href="<?php echo esc_url(admin_url('edit.php?post_type=shop_order')); ?>"><?php esc_html_e('View Orders', 'cargohub'); ?></a></li>
                        <li><a href="<?php echo esc_url(admin_url('edit.php?post_type=product')); ?>"><?php esc_html_e('Manage Products', 'cargohub'); ?></a></li>
                    </ul>
                </div>
            </div>
        </div>
    </div>
    
    <div class="cargohub-dashboard-widgets">
        <div class="metabox-holder">
            <div class="postbox-container" style="width: 49%; float: left; margin-right: 2%;">
                <div class="postbox">
                    <h2 class="hndle"><span><?php esc_html_e('Order Statistics', 'cargohub'); ?></span></h2>
                    <div class="inside">
                        <div class="main">
                            <ul class="cargohub-stats">
                                <li>
                                    <strong><?php echo esc_html($total_orders); ?></strong>
                                    <span><?php esc_html_e('Total Courier Orders', 'cargohub'); ?></span>
                                </li>
                                <li>
                                    <strong><?php echo esc_html($cod_orders); ?></strong>
                                    <span><?php esc_html_e('COD Orders', 'cargohub'); ?></span>
                                </li>
                            </ul>
                            
                            <h4><?php esc_html_e('Orders by Service Type', 'cargohub'); ?></h4>
                            <table class="widefat cargohub-table">
                                <thead>
                                    <tr>
                                        <th><?php esc_html_e('Service Type', 'cargohub'); ?></th>
                                        <th><?php esc_html_e('Orders', 'cargohub'); ?></th>
                                    </tr>
                                </thead>
                                <tbody>
                                    <?php if (empty($service_type_orders)) : ?>
                                        <tr>
                                            <td colspan="2"><?php esc_html_e('No orders yet.', 'cargohub'); ?></td>
                                        </tr>
                                    <?php else : ?>
                                        <?php foreach ($service_type_orders as $order_type) : ?>
                                            <tr>
                                                <td>
                                                    <?php 
                                                    if (isset($service_type_lookup[$order_type->service_type])) {
                                                        echo esc_html($service_type_lookup[$order_type->service_type]);
                                                    } else {
                                                        echo esc_html($order_type->service_type);
                                                    }
                                                    ?>
                                                </td>
                                                <td><?php echo esc_html($order_type->count); ?></td>
                                            </tr>
                                        <?php endforeach; ?>
                                    <?php endif; ?>
                                </tbody>
                            </table>
                        </div>
                    </div>
                </div>
            </div>
            
            <div class="postbox-container" style="width: 49%; float: left;">
                <div class="postbox">
                    <h2 class="hndle"><span><?php esc_html_e('Recent Orders', 'cargohub'); ?></span></h2>
                    <div class="inside">
                        <div class="main">
                            <table class="widefat cargohub-table">
                                <thead>
                                    <tr>
                                        <th><?php esc_html_e('Order', 'cargohub'); ?></th>
                                        <th><?php esc_html_e('Date', 'cargohub'); ?></th>
                                        <th><?php esc_html_e('Service Type', 'cargohub'); ?></th>
                                        <th><?php esc_html_e('Actions', 'cargohub'); ?></th>
                                    </tr>
                                </thead>
                                <tbody>
                                    <?php if (empty($recent_orders)) : ?>
                                        <tr>
                                            <td colspan="4"><?php esc_html_e('No orders yet.', 'cargohub'); ?></td>
                                        </tr>
                                    <?php else : ?>
                                        <?php foreach ($recent_orders as $order) : 
                                            $order_obj = wc_get_order($order->order_id);
                                            if (!$order_obj) continue;
                                            
                                            $order_number = $order_obj->get_order_number();
                                            $order_status = $order_obj->get_status();
                                            ?>
                                            <tr>
                                                <td>
                                                    <a href="<?php echo esc_url(admin_url('post.php?post=' . $order->order_id . '&action=edit')); ?>">
                                                        #<?php echo esc_html($order_number); ?>
                                                    </a>
                                                    <span class="order-status status-<?php echo esc_attr($order_status); ?>">
                                                        <?php echo esc_html(wc_get_order_status_name($order_status)); ?>
                                                    </span>
                                                </td>
                                                <td>
                                                    <?php echo esc_html(date_i18n(get_option('date_format'), strtotime($order->post_date))); ?>
                                                </td>
                                                <td>
                                                    <?php 
                                                    if (isset($service_type_lookup[$order->service_type])) {
                                                        echo esc_html($service_type_lookup[$order->service_type]);
                                                    } else {
                                                        echo esc_html($order->service_type);
                                                    }
                                                    ?>
                                                </td>
                                                <td>
                                                    <a href="<?php echo esc_url(admin_url('post.php?post=' . $order->order_id . '&action=edit')); ?>" class="button button-small">
                                                        <?php esc_html_e('View', 'cargohub'); ?>
                                                    </a>
                                                </td>
                                            </tr>
                                        <?php endforeach; ?>
                                    <?php endif; ?>
                                </tbody>
                            </table>
                            
                            <p class="cargohub-dashboard-actions">
                                <a href="<?php echo esc_url(admin_url('edit.php?post_type=shop_order')); ?>" class="button">
                                    <?php esc_html_e('View All Orders', 'cargohub'); ?>
                                </a>
                            </p>
                        </div>
                    </div>
                </div>
            </div>
            
            <div class="clear"></div>
            
            <div class="postbox-container" style="width: 100%;">
                <div class="postbox">
                    <h2 class="hndle"><span><?php esc_html_e('Service Types & Rates', 'cargohub'); ?></span></h2>
                    <div class="inside">
                        <div class="main">
                            <div class="cargohub-half-col">
                                <h4><?php esc_html_e('Active Service Types', 'cargohub'); ?></h4>
                                <table class="widefat cargohub-table">
                                    <thead>
                                        <tr>
                                            <th><?php esc_html_e('Service Name', 'cargohub'); ?></th>
                                            <th><?php esc_html_e('Code', 'cargohub'); ?></th>
                                        </tr>
                                    </thead>
                                    <tbody>
                                        <?php if (empty($service_types)) : ?>
                                            <tr>
                                                <td colspan="2"><?php esc_html_e('No service types defined.', 'cargohub'); ?></td>
                                            </tr>
                                        <?php else : ?>
                                            <?php foreach ($service_types as $service_type) : ?>
                                                <tr>
                                                    <td><?php echo esc_html($service_type->service_name); ?></td>
                                                    <td><code><?php echo esc_html($service_type->service_code); ?></code></td>
                                                </tr>
                                            <?php endforeach; ?>
                                        <?php endif; ?>
                                    </tbody>
                                </table>
                                
                                <p>
                                    <a href="<?php echo esc_url(admin_url('admin.php?page=cargohub-service-types')); ?>" class="button">
                                        <?php esc_html_e('Manage Service Types', 'cargohub'); ?>
                                    </a>
                                </p>
                            </div>
                            
                            <div class="cargohub-half-col">
                                <?php 
                                // Get zones information
                                $zones = $wpdb->get_results("
                                    SELECT id, zone_name
                                    FROM {$wpdb->prefix}cargohub_zones
                                    ORDER BY zone_name
                                ");
                                ?>
                                
                                <h4><?php esc_html_e('Shipping Zones', 'cargohub'); ?></h4>
                                <table class="widefat cargohub-table">
                                    <thead>
                                        <tr>
                                            <th><?php esc_html_e('Zone Name', 'cargohub'); ?></th>
                                            <th><?php esc_html_e('Rate Count', 'cargohub'); ?></th>
                                        </tr>
                                    </thead>
                                    <tbody>
                                        <?php if (empty($zones)) : ?>
                                            <tr>
                                                <td colspan="2"><?php esc_html_e('No zones defined.', 'cargohub'); ?></td>
                                            </tr>
                                        <?php else : ?>
                                            <?php foreach ($zones as $zone) : 
                                                // Get rate count for this zone
                                                $rate_count = $wpdb->get_var($wpdb->prepare("
                                                    SELECT COUNT(*)
                                                    FROM {$wpdb->prefix}cargohub_rates
                                                    WHERE zone_id = %d
                                                ", $zone->id));
                                                ?>
                                                <tr>
                                                    <td><?php echo esc_html($zone->zone_name); ?></td>
                                                    <td><?php echo esc_html($rate_count); ?></td>
                                                </tr>
                                            <?php endforeach; ?>
                                        <?php endif; ?>
                                    </tbody>
                                </table>
                                
                                <p>
                                    <a href="<?php echo esc_url(admin_url('admin.php?page=cargohub-zones')); ?>" class="button">
                                        <?php esc_html_e('Manage Zones', 'cargohub'); ?>
                                    </a>
                                    <a href="<?php echo esc_url(admin_url('admin.php?page=cargohub-rates')); ?>" class="button">
                                        <?php esc_html_e('Manage Rates', 'cargohub'); ?>
                                    </a>
                                </p>
                            </div>
                            
                            <div class="clear"></div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>

<style>
    .cargohub-welcome-panel {
        padding: 23px 10px 0;
        margin: 20px 0;
        background: #fff;
        border: 1px solid #ccd0d4;
        box-shadow: 0 1px 1px rgba(0,0,0,.04);
    }
    .cargohub-welcome-panel-content {
        margin-left: 13px;
        max-width: 1500px;
    }
    .cargohub-welcome-panel .about-description {
        margin: 13px 0;
        font-size: 16px;
    }
    .cargohub-welcome-panel-column-container {
        display: flex;
        flex-wrap: wrap;
    }
    .cargohub-welcome-panel-column {
        flex: 1;
        min-width: 200px;
        margin-bottom: 13px;
    }
    .cargohub-dashboard-widgets {
        margin-top: 20px;
    }
    .cargohub-stats {
        display: flex;
        flex-wrap: wrap;
        margin: 0 -10px;
        padding: 0;
    }
    .cargohub-stats li {
        margin: 0 10px 20px;
        padding: 0;
        flex: 1;
        min-width: 150px;
        text-align: center;
        background: #f9f9f9;
        border: 1px solid #e5e5e5;
        border-radius: 4px;
        padding: 15px;
    }
    .cargohub-stats li strong {
        display: block;
        font-size: 24px;
        line-height: 1.4;
        color: #23282d;
        margin-bottom: 5px;
    }
    .cargohub-table {
        margin-top: 10px;
    }
    .cargohub-dashboard-actions {
        margin-top: 15px;
        text-align: right;
    }
    .cargohub-half-col {
        width: 48%;
        float: left;
        margin-right: 4%;
    }
    .cargohub-half-col:last-child {
        margin-right: 0;
    }
    .clear {
        clear: both;
    }
    .order-status {
        display: inline-block;
        padding: 3px 5px;
        border-radius: 3px;
        font-size: 11px;
        margin-left: 5px;
        color: #fff;
    }
    .status-pending {
        background-color: #ffba00;
    }
    .status-processing {
        background-color: #73a724;
    }
    .status-completed {
        background-color: #2ea2cc;
    }
    .status-on-hold {
        background-color: #999;
    }
</style>