<?php
/**
 * Admin View: Service Types
 *
 * @package CargoHub
 */

// Exit if accessed directly.
if (!defined('WPINC')) {
    exit;
}

// Get service types from database
global $wpdb;
$table_name = $wpdb->prefix . 'cargohub_service_types';
$service_types = $wpdb->get_results("SELECT * FROM $table_name ORDER BY service_name ASC");

?>
<div class="wrap cargohub-service-types">
    <h1 class="wp-heading-inline"><?php esc_html_e('Service Types', 'cargohub'); ?></h1>
    <a href="#" class="page-title-action add-new-service-type"><?php esc_html_e('Add New Service Type', 'cargohub'); ?></a>
    <hr class="wp-header-end">
    
    <div id="ajax-response"></div>
    
    <div class="notice notice-info inline">
        <p><?php esc_html_e('Service types define the delivery options available to your customers. Standard and Express delivery are common examples.', 'cargohub'); ?></p>
    </div>
    
    <div id="col-container" class="wp-clearfix">
        <div id="col-left">
            <div class="col-wrap">
                <div class="form-wrap">
                    <h2><?php esc_html_e('Add New Service Type', 'cargohub'); ?></h2>
                    <form id="add-service-type" method="post">
                        <div class="form-field">
                            <label for="service_name"><?php esc_html_e('Service Name', 'cargohub'); ?></label>
                            <input type="text" name="service_name" id="service_name" value="" required>
                            <p><?php esc_html_e('The name of the service type as shown to customers.', 'cargohub'); ?></p>
                        </div>
                        
                        <div class="form-field">
                            <label for="service_code"><?php esc_html_e('Service Code', 'cargohub'); ?></label>
                            <input type="text" name="service_code" id="service_code" value="" required>
                            <p><?php esc_html_e('A unique code used to identify this service type in the system.', 'cargohub'); ?></p>
                        </div>
                        
                        <div class="form-field">
                            <label for="description"><?php esc_html_e('Description', 'cargohub'); ?></label>
                            <textarea name="description" id="description" rows="5" cols="40"></textarea>
                            <p><?php esc_html_e('Optional description for this service type.', 'cargohub'); ?></p>
                        </div>
                        
                        <div class="form-field">
                            <label for="active">
                                <input type="checkbox" name="active" id="active" value="1" checked>
                                <?php esc_html_e('Active', 'cargohub'); ?>
                            </label>
                            <p><?php esc_html_e('Only active service types are shown to customers.', 'cargohub'); ?></p>
                        </div>
                        
                        <p class="submit">
                            <input type="hidden" name="cargohub_action" value="save_service_type">
                            <input type="hidden" name="id" value="">
                            <input type="hidden" name="nonce" value="<?php echo esc_attr(wp_create_nonce('cargohub-admin-nonce')); ?>">
                            <button type="submit" class="button button-primary" id="submit-service-type"><?php esc_html_e('Add New Service Type', 'cargohub'); ?></button>
                        </p>
                    </form>
                </div>
            </div>
        </div>
        
        <div id="col-right">
            <div class="col-wrap">
                <table class="widefat fixed striped" id="service-type-table">
                    <thead>
                        <tr>
                            <th scope="col" class="manage-column column-name"><?php esc_html_e('Service Name', 'cargohub'); ?></th>
                            <th scope="col" class="manage-column column-code"><?php esc_html_e('Service Code', 'cargohub'); ?></th>
                            <th scope="col" class="manage-column column-description"><?php esc_html_e('Description', 'cargohub'); ?></th>
                            <th scope="col" class="manage-column column-status"><?php esc_html_e('Status', 'cargohub'); ?></th>
                            <th scope="col" class="manage-column column-actions"><?php esc_html_e('Actions', 'cargohub'); ?></th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($service_types)) : ?>
                            <tr class="no-items">
                                <td class="colspanchange" colspan="5"><?php esc_html_e('No service types found.', 'cargohub'); ?></td>
                            </tr>
                        <?php else : ?>
                            <?php foreach ($service_types as $service_type) : ?>
                                <tr data-id="<?php echo esc_attr($service_type->id); ?>">
                                    <td class="column-name">
                                        <strong><?php echo esc_html($service_type->service_name); ?></strong>
                                    </td>
                                    <td class="column-code">
                                        <code><?php echo esc_html($service_type->service_code); ?></code>
                                    </td>
                                    <td class="column-description">
                                        <?php echo !empty($service_type->description) ? esc_html($service_type->description) : '—'; ?>
                                    </td>
                                    <td class="column-status">
                                        <?php if ($service_type->active) : ?>
                                            <span class="status-active"><?php esc_html_e('Active', 'cargohub'); ?></span>
                                        <?php else : ?>
                                            <span class="status-inactive"><?php esc_html_e('Inactive', 'cargohub'); ?></span>
                                        <?php endif; ?>
                                    </td>
                                    <td class="column-actions">
                                        <a href="#" class="edit-service-type" 
                                           data-id="<?php echo esc_attr($service_type->id); ?>"
                                           data-name="<?php echo esc_attr($service_type->service_name); ?>"
                                           data-code="<?php echo esc_attr($service_type->service_code); ?>"
                                           data-description="<?php echo esc_attr($service_type->description); ?>"
                                           data-active="<?php echo esc_attr($service_type->active); ?>">
                                            <?php esc_html_e('Edit', 'cargohub'); ?>
                                        </a> | 
                                        <a href="#" class="delete-service-type" data-id="<?php echo esc_attr($service_type->id); ?>">
                                            <?php esc_html_e('Delete', 'cargohub'); ?>
                                        </a>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                    <tfoot>
                        <tr>
                            <th scope="col" class="manage-column column-name"><?php esc_html_e('Service Name', 'cargohub'); ?></th>
                            <th scope="col" class="manage-column column-code"><?php esc_html_e('Service Code', 'cargohub'); ?></th>
                            <th scope="col" class="manage-column column-description"><?php esc_html_e('Description', 'cargohub'); ?></th>
                            <th scope="col" class="manage-column column-status"><?php esc_html_e('Status', 'cargohub'); ?></th>
                            <th scope="col" class="manage-column column-actions"><?php esc_html_e('Actions', 'cargohub'); ?></th>
                        </tr>
                    </tfoot>
                </table>
            </div>
        </div>
    </div>
</div>

<script type="text/javascript">
jQuery(document).ready(function($) {
    // Handle form submission
    $('#add-service-type').on('submit', function(e) {
        e.preventDefault();
        
        var form = $(this);
        var submitButton = $('#submit-service-type');
        var formData = {
            'cargohub_action': form.find('input[name="cargohub_action"]').val(),
            'id': form.find('input[name="id"]').val(),
            'service_name': form.find('input[name="service_name"]').val(),
            'service_code': form.find('input[name="service_code"]').val(),
            'description': form.find('textarea[name="description"]').val(),
            'active': form.find('input[name="active"]').is(':checked') ? 1 : 0,
            'nonce': form.find('input[name="nonce"]').val(),
            'action': 'cargohub_admin_action'
        };
        
        // Disable submit button and show loading
        submitButton.prop('disabled', true).text(
            form.find('input[name="id"]').val() ? 
            '<?php esc_html_e('Updating...', 'cargohub'); ?>' : 
            '<?php esc_html_e('Adding...', 'cargohub'); ?>'
        );
        
        $.ajax({
            type: 'POST',
            url: ajaxurl,
            data: formData,
            success: function(response) {
                if (response.success) {
                    // Show success message
                    $('#ajax-response').html('<div class="notice notice-success is-dismissible"><p>' + response.data.message + '</p></div>');
                    
                    // Reset form if adding new
                    if (!form.find('input[name="id"]').val()) {
                        form.find('input[name="service_name"]').val('');
                        form.find('input[name="service_code"]').val('');
                        form.find('textarea[name="description"]').val('');
                        form.find('input[name="active"]').prop('checked', true);
                    }
                    
                    // Reload the page to update the table
                    setTimeout(function() {
                        location.reload();
                    }, 1000);
                } else {
                    // Show error message
                    $('#ajax-response').html('<div class="notice notice-error is-dismissible"><p>' + response.data.message + '</p></div>');
                    
                    // Re-enable submit button
                    submitButton.prop('disabled', false).text(
                        form.find('input[name="id"]').val() ? 
                        '<?php esc_html_e('Update Service Type', 'cargohub'); ?>' : 
                        '<?php esc_html_e('Add New Service Type', 'cargohub'); ?>'
                    );
                }
            },
            error: function() {
                // Show error message
                $('#ajax-response').html('<div class="notice notice-error is-dismissible"><p><?php esc_html_e('An error occurred. Please try again.', 'cargohub'); ?></p></div>');
                
                // Re-enable submit button
                submitButton.prop('disabled', false).text(
                    form.find('input[name="id"]').val() ? 
                    '<?php esc_html_e('Update Service Type', 'cargohub'); ?>' : 
                    '<?php esc_html_e('Add New Service Type', 'cargohub'); ?>'
                );
            }
        });
    });
    
    // Handle edit click
    $('.edit-service-type').on('click', function(e) {
        e.preventDefault();
        
        var id = $(this).data('id');
        var name = $(this).data('name');
        var code = $(this).data('code');
        var description = $(this).data('description');
        var active = $(this).data('active');
        
        // Populate form
        $('#service_name').val(name);
        $('#service_code').val(code);
        $('#description').val(description);
        $('#active').prop('checked', active == 1);
        
        // Change form to edit mode
        $('input[name="id"]').val(id);
        $('#submit-service-type').text('<?php esc_html_e('Update Service Type', 'cargohub'); ?>');
        $('h2:first').text('<?php esc_html_e('Edit Service Type', 'cargohub'); ?>');
        
        // Scroll to form
        $('html, body').animate({
            scrollTop: $('#add-service-type').offset().top - 50
        }, 500);
    });
    
    // Handle delete click
    $('.delete-service-type').on('click', function(e) {
        e.preventDefault();
        
        var id = $(this).data('id');
        
        if (confirm('<?php esc_html_e('Are you sure you want to delete this service type? This action cannot be undone.', 'cargohub'); ?>')) {
            $.ajax({
                type: 'POST',
                url: ajaxurl,
                data: {
                    'action': 'cargohub_admin_action',
                    'cargohub_action': 'delete_service_type',
                    'id': id,
                    'nonce': '<?php echo wp_create_nonce('cargohub-admin-nonce'); ?>'
                },
                success: function(response) {
                    if (response.success) {
                        // Show success message
                        $('#ajax-response').html('<div class="notice notice-success is-dismissible"><p>' + response.data.message + '</p></div>');
                        
                        // Remove row from table
                        $('tr[data-id="' + id + '"]').fadeOut(400, function() {
                            $(this).remove();
                            
                            // Check if table is empty
                            if ($('#service-type-table tbody tr').length === 0) {
                                $('#service-type-table tbody').html('<tr class="no-items"><td class="colspanchange" colspan="5"><?php esc_html_e('No service types found.', 'cargohub'); ?></td></tr>');
                            }
                        });
                    } else {
                        // Show error message
                        $('#ajax-response').html('<div class="notice notice-error is-dismissible"><p>' + response.data.message + '</p></div>');
                    }
                },
                error: function() {
                    // Show error message
                    $('#ajax-response').html('<div class="notice notice-error is-dismissible"><p><?php esc_html_e('An error occurred. Please try again.', 'cargohub'); ?></p></div>');
                }
            });
        }
    });
    
    // Handle add new click
    $('.add-new-service-type').on('click', function(e) {
        e.preventDefault();
        
        // Reset form
        $('#add-service-type')[0].reset();
        $('input[name="id"]').val('');
        $('#submit-service-type').text('<?php esc_html_e('Add New Service Type', 'cargohub'); ?>');
        $('h2:first').text('<?php esc_html_e('Add New Service Type', 'cargohub'); ?>');
        
        // Scroll to form
        $('html, body').animate({
            scrollTop: $('#add-service-type').offset().top - 50
        }, 500);
    });
});
</script>

<style>
.status-active {
    background-color: #c6e1c6;
    color: #5b841b;
    padding: 3px 6px;
    border-radius: 3px;
    font-size: 12px;
}
.status-inactive {
    background-color: #f8dda7;
    color: #94660c;
    padding: 3px 6px;
    border-radius: 3px;
    font-size: 12px;
}
.column-code {
    width: 15%;
}
.column-status {
    width: 10%;
}
.column-actions {
    width: 15%;
}
</style>