<?php
/**
 * Admin View: Settings
 *
 * @package CargoHub
 */

// Exit if accessed directly.
if (!defined('WPINC')) {
    exit;
}

// Get active tab
$active_tab = isset($_GET['tab']) ? sanitize_text_field($_GET['tab']) : 'general';

?>
<div class="wrap cargohub-settings">
    <h1><?php esc_html_e('CargoHub Settings', 'cargohub'); ?></h1>
    
    <h2 class="nav-tab-wrapper">
        <a href="<?php echo esc_url(admin_url('admin.php?page=cargohub-settings&tab=general')); ?>" class="nav-tab <?php echo $active_tab == 'general' ? 'nav-tab-active' : ''; ?>">
            <?php esc_html_e('General', 'cargohub'); ?>
        </a>
        <a href="<?php echo esc_url(admin_url('admin.php?page=cargohub-settings&tab=display')); ?>" class="nav-tab <?php echo $active_tab == 'display' ? 'nav-tab-active' : ''; ?>">
            <?php esc_html_e('Display', 'cargohub'); ?>
        </a>
        <a href="<?php echo esc_url(admin_url('admin.php?page=cargohub-settings&tab=advanced')); ?>" class="nav-tab <?php echo $active_tab == 'advanced' ? 'nav-tab-active' : ''; ?>">
            <?php esc_html_e('Advanced', 'cargohub'); ?>
        </a>
    </h2>
    
    <div id="tab-content">
        <?php if ($active_tab == 'general') : ?>
            
            <form method="post" action="options.php">
                <?php
                // Output security fields
                settings_fields('cargohub_settings');
                
                // Output settings sections
                do_settings_sections('cargohub_settings');
                
                // Output save button
                submit_button();
                ?>
            </form>
            
        <?php elseif ($active_tab == 'display') : ?>
            
            <form method="post" action="options.php">
                <?php
                // Output security fields
                settings_fields('cargohub_display_settings');
                
                // Output settings sections
                do_settings_sections('cargohub_display_settings');
                
                // Output save button
                submit_button();
                ?>
            </form>
            
        <?php elseif ($active_tab == 'advanced') : ?>
            
            <div class="cargohub-advanced-settings">
                <h2><?php esc_html_e('Database Tools', 'cargohub'); ?></h2>
                
                <div class="card">
                    <h3><?php esc_html_e('Clear Data', 'cargohub'); ?></h3>
                    <p><?php esc_html_e('This will clear all shipping rates data from the database. Useful if you want to start fresh.', 'cargohub'); ?></p>
                    <p><strong><?php esc_html_e('Warning: This action cannot be undone. Please backup your database before proceeding.', 'cargohub'); ?></strong></p>
                    <p>
                        <button type="button" class="button clear-rates-data"><?php esc_html_e('Clear Shipping Rates', 'cargohub'); ?></button>
                    </p>
                </div>
                
                <div class="card">
                    <h3><?php esc_html_e('Reset to Defaults', 'cargohub'); ?></h3>
                    <p><?php esc_html_e('This will reset all settings to their default values. Useful if you want to start over with the configuration.', 'cargohub'); ?></p>
                    <p><strong><?php esc_html_e('Warning: This action cannot be undone.', 'cargohub'); ?></strong></p>
                    <p>
                        <button type="button" class="button reset-settings"><?php esc_html_e('Reset Settings', 'cargohub'); ?></button>
                    </p>
                </div>
                
                <div class="card">
                    <h3><?php esc_html_e('Export/Import Settings', 'cargohub'); ?></h3>
                    <p><?php esc_html_e('Export your settings to a JSON file or import settings from a previously exported file.', 'cargohub'); ?></p>
                    <p>
                        <button type="button" class="button export-settings"><?php esc_html_e('Export Settings', 'cargohub'); ?></button>
                        <button type="button" class="button import-settings"><?php esc_html_e('Import Settings', 'cargohub'); ?></button>
                        <input type="file" id="import-settings-file" accept=".json" style="display: none;">
                    </p>
                </div>
            </div>
            
            <script type="text/javascript">
            jQuery(document).ready(function($) {
                // Handle clear rates data
                $('.clear-rates-data').on('click', function() {
                    if (confirm('<?php esc_html_e('Are you sure you want to clear all shipping rates? This action cannot be undone.', 'cargohub'); ?>')) {
                        $.ajax({
                            type: 'POST',
                            url: ajaxurl,
                            data: {
                                'action': 'cargohub_admin_action',
                                'cargohub_action': 'clear_rates_data',
                                'nonce': '<?php echo wp_create_nonce('cargohub-admin-nonce'); ?>'
                            },
                            success: function(response) {
                                if (response.success) {
                                    alert(response.data.message);
                                } else {
                                    alert(response.data.message || '<?php esc_html_e('An error occurred. Please try again.', 'cargohub'); ?>');
                                }
                            },
                            error: function() {
                                alert('<?php esc_html_e('An error occurred. Please try again.', 'cargohub'); ?>');
                            }
                        });
                    }
                });
                
                // Handle reset settings
                $('.reset-settings').on('click', function() {
                    if (confirm('<?php esc_html_e('Are you sure you want to reset all settings to default values? This action cannot be undone.', 'cargohub'); ?>')) {
                        $.ajax({
                            type: 'POST',
                            url: ajaxurl,
                            data: {
                                'action': 'cargohub_admin_action',
                                'cargohub_action': 'reset_settings',
                                'nonce': '<?php echo wp_create_nonce('cargohub-admin-nonce'); ?>'
                            },
                            success: function(response) {
                                if (response.success) {
                                    alert(response.data.message);
                                    window.location.reload();
                                } else {
                                    alert(response.data.message || '<?php esc_html_e('An error occurred. Please try again.', 'cargohub'); ?>');
                                }
                            },
                            error: function() {
                                alert('<?php esc_html_e('An error occurred. Please try again.', 'cargohub'); ?>');
                            }
                        });
                    }
                });
                
                // Handle export settings
                $('.export-settings').on('click', function() {
                    $.ajax({
                        type: 'POST',
                        url: ajaxurl,
                        data: {
                            'action': 'cargohub_admin_action',
                            'cargohub_action': 'export_settings',
                            'nonce': '<?php echo wp_create_nonce('cargohub-admin-nonce'); ?>'
                        },
                        success: function(response) {
                            if (response.success) {
                                // Create a blob and download it
                                var dataStr = "data:text/json;charset=utf-8," + encodeURIComponent(JSON.stringify(response.data.settings));
                                var downloadAnchorNode = document.createElement('a');
                                downloadAnchorNode.setAttribute("href", dataStr);
                                downloadAnchorNode.setAttribute("download", "cargohub-settings.json");
                                document.body.appendChild(downloadAnchorNode);
                                downloadAnchorNode.click();
                                downloadAnchorNode.remove();
                            } else {
                                alert(response.data.message || '<?php esc_html_e('An error occurred. Please try again.', 'cargohub'); ?>');
                            }
                        },
                        error: function() {
                            alert('<?php esc_html_e('An error occurred. Please try again.', 'cargohub'); ?>');
                        }
                    });
                });
                
                // Handle import settings button
                $('.import-settings').on('click', function() {
                    $('#import-settings-file').click();
                });
                
                // Handle file selection
                $('#import-settings-file').on('change', function(e) {
                    var file = e.target.files[0];
                    if (!file) {
                        return;
                    }
                    
                    var reader = new FileReader();
                    reader.onload = function(e) {
                        try {
                            var settings = JSON.parse(e.target.result);
                            
                            if (confirm('<?php esc_html_e('Are you sure you want to import these settings? This will overwrite your current settings.', 'cargohub'); ?>')) {
                                $.ajax({
                                    type: 'POST',
                                    url: ajaxurl,
                                    data: {
                                        'action': 'cargohub_admin_action',
                                        'cargohub_action': 'import_settings',
                                        'settings': JSON.stringify(settings),
                                        'nonce': '<?php echo wp_create_nonce('cargohub-admin-nonce'); ?>'
                                    },
                                    success: function(response) {
                                        if (response.success) {
                                            alert(response.data.message);
                                            window.location.reload();
                                        } else {
                                            alert(response.data.message || '<?php esc_html_e('An error occurred. Please try again.', 'cargohub'); ?>');
                                        }
                                    },
                                    error: function() {
                                        alert('<?php esc_html_e('An error occurred. Please try again.', 'cargohub'); ?>');
                                    }
                                });
                            }
                        } catch (error) {
                            alert('<?php esc_html_e('Invalid settings file. Please select a valid JSON file.', 'cargohub'); ?>');
                        }
                    };
                    reader.readAsText(file);
                });
            });
            </script>
            
        <?php endif; ?>
    </div>
</div>

<style>
.card {
    background: #fff;
    border: 1px solid #ccd0d4;
    border-radius: 3px;
    margin-top: 20px;
    padding: 0.7em 2em 1em;
    max-width: 600px;
    position: relative;
    box-shadow: 0 1px 1px rgba(0,0,0,0.04);
}
</style>