<?php
/**
 * Admin View: Shipping Zones
 *
 * @package CargoHub
 */

// Exit if accessed directly.
if (!defined('WPINC')) {
    exit;
}

// Get zones from database
global $wpdb;
$table_name = $wpdb->prefix . 'cargohub_zones';
$zones = $wpdb->get_results("SELECT * FROM $table_name ORDER BY zone_name ASC");

// Get WooCommerce countries
$countries = WC()->countries->get_countries();

?>
<div class="wrap cargohub-zones">
    <h1 class="wp-heading-inline"><?php esc_html_e('Shipping Zones', 'cargohub'); ?></h1>
    <a href="#" class="page-title-action add-new-zone"><?php esc_html_e('Add New Zone', 'cargohub'); ?></a>
    <hr class="wp-header-end">
    
    <div id="ajax-response"></div>
    
    <div class="notice notice-info inline">
        <p><?php esc_html_e('Shipping zones are geographic regions where a specific set of shipping rates apply. For example, you might define zones for "Domestic", "Europe", and "International".', 'cargohub'); ?></p>
    </div>
    
    <div id="col-container" class="wp-clearfix">
        <div id="col-left">
            <div class="col-wrap">
                <div class="form-wrap">
                    <h2><?php esc_html_e('Add New Shipping Zone', 'cargohub'); ?></h2>
                    <form id="add-zone" method="post">
                        <div class="form-field">
                            <label for="zone_name"><?php esc_html_e('Zone Name', 'cargohub'); ?></label>
                            <input type="text" name="zone_name" id="zone_name" value="" required>
                            <p><?php esc_html_e('The name of the shipping zone for your reference.', 'cargohub'); ?></p>
                        </div>
                        
                        <div class="form-field">
                            <label for="countries"><?php esc_html_e('Countries', 'cargohub'); ?></label>
                            <select name="countries[]" id="countries" class="wc-enhanced-select" multiple="multiple" style="width: 100%;" required>
                                <?php foreach ($countries as $code => $name) : ?>
                                    <option value="<?php echo esc_attr($code); ?>"><?php echo esc_html($name); ?></option>
                                <?php endforeach; ?>
                            </select>
                            <p><?php esc_html_e('Select the countries that belong to this shipping zone. Hold Ctrl/Cmd to select multiple countries.', 'cargohub'); ?></p>
                        </div>
                        
                        <p class="submit">
                            <input type="hidden" name="cargohub_action" value="save_zone">
                            <input type="hidden" name="id" value="">
                            <input type="hidden" name="nonce" value="<?php echo esc_attr(wp_create_nonce('cargohub-admin-nonce')); ?>">
                            <button type="submit" class="button button-primary" id="submit-zone"><?php esc_html_e('Add New Zone', 'cargohub'); ?></button>
                        </p>
                    </form>
                </div>
            </div>
        </div>
        
        <div id="col-right">
            <div class="col-wrap">
                <table class="widefat fixed striped" id="zone-table">
                    <thead>
                        <tr>
                            <th scope="col" class="manage-column column-name"><?php esc_html_e('Zone Name', 'cargohub'); ?></th>
                            <th scope="col" class="manage-column column-countries"><?php esc_html_e('Countries', 'cargohub'); ?></th>
                            <th scope="col" class="manage-column column-rates"><?php esc_html_e('Rate Count', 'cargohub'); ?></th>
                            <th scope="col" class="manage-column column-actions"><?php esc_html_e('Actions', 'cargohub'); ?></th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($zones)) : ?>
                            <tr class="no-items">
                                <td class="colspanchange" colspan="4"><?php esc_html_e('No zones found.', 'cargohub'); ?></td>
                            </tr>
                        <?php else : ?>
                            <?php foreach ($zones as $zone) : 
                                // Get countries for this zone
                                $zone_countries = unserialize($zone->countries);
                                
                                // Get rate count for this zone
                                $rates_table = $wpdb->prefix . 'cargohub_rates';
                                $rate_count = $wpdb->get_var($wpdb->prepare("
                                    SELECT COUNT(*) FROM $rates_table WHERE zone_id = %d
                                ", $zone->id));
                                ?>
                                <tr data-id="<?php echo esc_attr($zone->id); ?>">
                                    <td class="column-name">
                                        <strong><?php echo esc_html($zone->zone_name); ?></strong>
                                    </td>
                                    <td class="column-countries">
                                        <?php 
                                        if (!empty($zone_countries)) {
                                            $country_names = array();
                                            foreach ($zone_countries as $country_code) {
                                                if (isset($countries[$country_code])) {
                                                    $country_names[] = $countries[$country_code];
                                                }
                                            }
                                            if (count($country_names) > 5) {
                                                echo esc_html(implode(', ', array_slice($country_names, 0, 5))) . ' ' . 
                                                     sprintf(esc_html__('and %d more', 'cargohub'), count($country_names) - 5);
                                            } else {
                                                echo esc_html(implode(', ', $country_names));
                                            }
                                        } else {
                                            echo '—';
                                        }
                                        ?>
                                    </td>
                                    <td class="column-rates">
                                        <?php echo esc_html($rate_count); ?>
                                        <?php if ($rate_count > 0) : ?>
                                            <a href="<?php echo esc_url(admin_url('admin.php?page=cargohub-rates&zone=' . $zone->id)); ?>" class="view-rates">
                                                <?php esc_html_e('View', 'cargohub'); ?>
                                            </a>
                                        <?php endif; ?>
                                    </td>
                                    <td class="column-actions">
                                        <a href="#" class="edit-zone" 
                                           data-id="<?php echo esc_attr($zone->id); ?>"
                                           data-name="<?php echo esc_attr($zone->zone_name); ?>"
                                           data-countries="<?php echo esc_attr(implode(',', $zone_countries)); ?>">
                                            <?php esc_html_e('Edit', 'cargohub'); ?>
                                        </a> | 
                                        <a href="#" class="delete-zone" data-id="<?php echo esc_attr($zone->id); ?>">
                                            <?php esc_html_e('Delete', 'cargohub'); ?>
                                        </a>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                    <tfoot>
                        <tr>
                            <th scope="col" class="manage-column column-name"><?php esc_html_e('Zone Name', 'cargohub'); ?></th>
                            <th scope="col" class="manage-column column-countries"><?php esc_html_e('Countries', 'cargohub'); ?></th>
                            <th scope="col" class="manage-column column-rates"><?php esc_html_e('Rate Count', 'cargohub'); ?></th>
                            <th scope="col" class="manage-column column-actions"><?php esc_html_e('Actions', 'cargohub'); ?></th>
                        </tr>
                    </tfoot>
                </table>
            </div>
        </div>
    </div>
</div>

<script type="text/javascript">
jQuery(document).ready(function($) {
    // Initialize select2 for country selection
    $('#countries').select2();
    
    // Handle form submission
    $('#add-zone').on('submit', function(e) {
        e.preventDefault();
        
        var form = $(this);
        var submitButton = $('#submit-zone');
        var countries = $('#countries').val();
        
        if (!countries || countries.length === 0) {
            alert('<?php esc_html_e('Please select at least one country for the shipping zone.', 'cargohub'); ?>');
            return;
        }
        
        var formData = {
            'cargohub_action': form.find('input[name="cargohub_action"]').val(),
            'id': form.find('input[name="id"]').val(),
            'zone_name': form.find('input[name="zone_name"]').val(),
            'countries': countries,
            'nonce': form.find('input[name="nonce"]').val(),
            'action': 'cargohub_admin_action'
        };
        
        // Disable submit button and show loading
        submitButton.prop('disabled', true).text(
            form.find('input[name="id"]').val() ? 
            '<?php esc_html_e('Updating...', 'cargohub'); ?>' : 
            '<?php esc_html_e('Adding...', 'cargohub'); ?>'
        );
        
        $.ajax({
            type: 'POST',
            url: ajaxurl,
            data: formData,
            success: function(response) {
                if (response.success) {
                    // Show success message
                    $('#ajax-response').html('<div class="notice notice-success is-dismissible"><p>' + response.data.message + '</p></div>');
                    
                    // Reset form if adding new
                    if (!form.find('input[name="id"]').val()) {
                        form.find('input[name="zone_name"]').val('');
                        $('#countries').val(null).trigger('change');
                    }
                    
                    // Reload the page to update the table
                    setTimeout(function() {
                        location.reload();
                    }, 1000);
                } else {
                    // Show error message
                    $('#ajax-response').html('<div class="notice notice-error is-dismissible"><p>' + response.data.message + '</p></div>');
                    
                    // Re-enable submit button
                    submitButton.prop('disabled', false).text(
                        form.find('input[name="id"]').val() ? 
                        '<?php esc_html_e('Update Zone', 'cargohub'); ?>' : 
                        '<?php esc_html_e('Add New Zone', 'cargohub'); ?>'
                    );
                }
            },
            error: function() {
                // Show error message
                $('#ajax-response').html('<div class="notice notice-error is-dismissible"><p><?php esc_html_e('An error occurred. Please try again.', 'cargohub'); ?></p></div>');
                
                // Re-enable submit button
                submitButton.prop('disabled', false).text(
                    form.find('input[name="id"]').val() ? 
                    '<?php esc_html_e('Update Zone', 'cargohub'); ?>' : 
                    '<?php esc_html_e('Add New Zone', 'cargohub'); ?>'
                );
            }
        });
    });
    
    // Handle edit click
    $('.edit-zone').on('click', function(e) {
        e.preventDefault();
        
        var id = $(this).data('id');
        var name = $(this).data('name');
        var countries = $(this).data('countries').split(',');
        
        // Populate form
        $('#zone_name').val(name);
        $('#countries').val(countries).trigger('change');
        
        // Change form to edit mode
        $('input[name="id"]').val(id);
        $('#submit-zone').text('<?php esc_html_e('Update Zone', 'cargohub'); ?>');
        $('h2:first').text('<?php esc_html_e('Edit Shipping Zone', 'cargohub'); ?>');
        
        // Scroll to form
        $('html, body').animate({
            scrollTop: $('#add-zone').offset().top - 50
        }, 500);
    });
    
    // Handle delete click
    $('.delete-zone').on('click', function(e) {
        e.preventDefault();
        
        var id = $(this).data('id');
        
        if (confirm('<?php esc_html_e('Are you sure you want to delete this shipping zone? This action cannot be undone.', 'cargohub'); ?>')) {
            $.ajax({
                type: 'POST',
                url: ajaxurl,
                data: {
                    'action': 'cargohub_admin_action',
                    'cargohub_action': 'delete_zone',
                    'id': id,
                    'nonce': '<?php echo wp_create_nonce('cargohub-admin-nonce'); ?>'
                },
                success: function(response) {
                    if (response.success) {
                        // Show success message
                        $('#ajax-response').html('<div class="notice notice-success is-dismissible"><p>' + response.data.message + '</p></div>');
                        
                        // Remove row from table
                        $('tr[data-id="' + id + '"]').fadeOut(400, function() {
                            $(this).remove();
                            
                            // Check if table is empty
                            if ($('#zone-table tbody tr').length === 0) {
                                $('#zone-table tbody').html('<tr class="no-items"><td class="colspanchange" colspan="4"><?php esc_html_e('No zones found.', 'cargohub'); ?></td></tr>');
                            }
                        });
                    } else {
                        // Show error message
                        $('#ajax-response').html('<div class="notice notice-error is-dismissible"><p>' + response.data.message + '</p></div>');
                    }
                },
                error: function() {
                    // Show error message
                    $('#ajax-response').html('<div class="notice notice-error is-dismissible"><p><?php esc_html_e('An error occurred. Please try again.', 'cargohub'); ?></p></div>');
                }
            });
        }
    });
    
    // Handle add new click
    $('.add-new-zone').on('click', function(e) {
        e.preventDefault();
        
        // Reset form
        $('#add-zone')[0].reset();
        $('input[name="id"]').val('');
        $('#countries').val(null).trigger('change');
        $('#submit-zone').text('<?php esc_html_e('Add New Zone', 'cargohub'); ?>');
        $('h2:first').text('<?php esc_html_e('Add New Shipping Zone', 'cargohub'); ?>');
        
        // Scroll to form
        $('html, body').animate({
            scrollTop: $('#add-zone').offset().top - 50
        }, 500);
    });
});
</script>

<style>
.column-countries {
    width: 45%;
}
.column-rates {
    width: 15%;
}
.column-actions {
    width: 15%;
}
.view-rates {
    margin-left: 10px;
    color: #0073aa;
    text-decoration: none;
}
.view-rates:hover {
    color: #00a0d2;
}
</style>