<?php
/**
 * Courier details in emails
 *
 * This template displays courier details in order emails.
 *
 * @package CargoHub
 */

defined('ABSPATH') || exit;

// Variables should be defined by wc_get_template
// $order (WC_Order) The order object
// $weight_unit (string) The weight unit (kg, lb, etc.)
// $dimension_unit (string) The dimension unit (cm, m, in, etc.)
// $service_type_name (string) The service type name

// Get order details
$weight = $order->get_meta('_cargohub_weight', true);
$volumetric_weight = $order->get_meta('_cargohub_volumetric_weight', true);
$length = $order->get_meta('_cargohub_length', true);
$width = $order->get_meta('_cargohub_width', true);
$height = $order->get_meta('_cargohub_height', true);
$cod_option = $order->get_meta('_cargohub_cod_option', true);

?>
<h2 style="color: #7f54b3; display: block; font-size: 18px; font-weight: bold; line-height: 130%; margin: 16px 0 8px; text-transform: uppercase;">
    <?php esc_html_e('Shipping Details', 'cargohub'); ?>
</h2>

<table cellspacing="0" cellpadding="6" style="width: 100%; border: 1px solid #e5e5e5; margin-bottom: 20px;">
    <tr>
        <th scope="row" style="text-align:left; border-bottom: 1px solid #e5e5e5; padding: 12px; font-weight: bold; color: #636363; width: 40%;">
            <?php esc_html_e('Service Type', 'cargohub'); ?>
        </th>
        <td style="text-align:left; border-bottom: 1px solid #e5e5e5; padding: 12px; color: #636363;">
            <?php echo esc_html($service_type_name); ?>
            <?php if ($cod_option === 'yes') : ?>
                <span style="background-color: #ffe5e5; color: #d63638; padding: 3px 5px; border-radius: 3px; font-size: 11px; display: inline-block; margin-left: 5px;">
                    <?php esc_html_e('COD', 'cargohub'); ?>
                </span>
            <?php endif; ?>
        </td>
    </tr>
    
    <tr>
        <th scope="row" style="text-align:left; border-bottom: 1px solid #e5e5e5; padding: 12px; font-weight: bold; color: #636363; width: 40%;">
            <?php esc_html_e('Weight', 'cargohub'); ?>
        </th>
        <td style="text-align:left; border-bottom: 1px solid #e5e5e5; padding: 12px; color: #636363;">
            <?php echo esc_html(wc_format_decimal($weight, 2)) . ' ' . esc_html($weight_unit); ?>
            
            <?php if (!empty($volumetric_weight) && $volumetric_weight > $weight) : ?>
                <br>
                <small>
                    <?php esc_html_e('Volumetric', 'cargohub'); ?>: 
                    <?php echo esc_html(wc_format_decimal($volumetric_weight, 2)) . ' ' . esc_html($weight_unit); ?>
                </small>
            <?php endif; ?>
        </td>
    </tr>
    
    <?php if (!empty($length) && !empty($width) && !empty($height)) : ?>
        <tr>
            <th scope="row" style="text-align:left; border-bottom: 1px solid #e5e5e5; padding: 12px; font-weight: bold; color: #636363; width: 40%;">
                <?php esc_html_e('Dimensions', 'cargohub'); ?>
            </th>
            <td style="text-align:left; border-bottom: 1px solid #e5e5e5; padding: 12px; color: #636363;">
                <?php 
                echo esc_html(wc_format_decimal($length, 1)) . ' × ';
                echo esc_html(wc_format_decimal($width, 1)) . ' × ';
                echo esc_html(wc_format_decimal($height, 1)) . ' ' . esc_html($dimension_unit);
                ?>
            </td>
        </tr>
    <?php endif; ?>
</table>