<?php
/**
 * Product dimension fields template
 *
 * @package CargoHub
 */

defined('ABSPATH') || exit;

// Variables should be defined by wc_get_template
// $weight_unit (string) The weight unit (kg, lb, etc.)
// $dimension_unit (string) The dimension unit (cm, m, in, etc.)
// $min_weight (float) The minimum allowed weight
// $max_weight (float) The maximum allowed weight
// $weight (string) The prefilled weight value
// $length (string) The prefilled length value
// $width (string) The prefilled width value
// $height (string) The prefilled height value

?>
<div class="cargohub-dimension-fields">
    <h3><?php esc_html_e('Package Details', 'cargohub'); ?></h3>
    
    <div class="cargohub-field-row">
        <label for="cargohub_weight"><?php 
            // Translators: %s is the weight unit (kg, lb, etc.)
            printf(esc_html__('Weight (%s)', 'cargohub'), esc_html($weight_unit)); 
        ?> <abbr class="required" title="<?php esc_attr_e('required', 'cargohub'); ?>">*</abbr></label>
        <input type="number" 
               id="cargohub_weight" 
               name="cargohub_weight" 
               value="<?php echo esc_attr($weight); ?>" 
               step="0.01" 
               min="<?php echo esc_attr($min_weight); ?>" 
               max="<?php echo esc_attr($max_weight); ?>" 
               required
               class="cargohub-input-field" />
        <p class="description">
            <?php 
            // Translators: %1$s is the minimum weight, %2$s is the maximum weight, %3$s is the weight unit
            printf(
                esc_html__('Enter the actual weight of your package (min: %1$s, max: %2$s %3$s).', 'cargohub'), 
                esc_html($min_weight), 
                esc_html($max_weight), 
                esc_html($weight_unit)
            ); 
            ?>
        </p>
    </div>
    
    <div class="cargohub-dimensions-container">
        <label><?php 
            // Translators: %s is the dimension unit (cm, in, etc.)
            printf(esc_html__('Dimensions (%s)', 'cargohub'), esc_html($dimension_unit)); 
        ?> <abbr class="required" title="<?php esc_attr_e('required', 'cargohub'); ?>">*</abbr></label>
        
        <div class="cargohub-dimensions-fields">
            <div class="cargohub-dimension-field">
                <input type="number" 
                       id="cargohub_length" 
                       name="cargohub_length" 
                       value="<?php echo esc_attr($length); ?>" 
                       step="0.1" 
                       min="0.1" 
                       required
                       class="cargohub-input-field" />
                <span class="cargohub-dimension-label"><?php esc_html_e('Length', 'cargohub'); ?></span>
            </div>
            
            <div class="cargohub-dimension-field">
                <input type="number" 
                       id="cargohub_width" 
                       name="cargohub_width" 
                       value="<?php echo esc_attr($width); ?>" 
                       step="0.1" 
                       min="0.1" 
                       required
                       class="cargohub-input-field" />
                <span class="cargohub-dimension-label"><?php esc_html_e('Width', 'cargohub'); ?></span>
            </div>
            
            <div class="cargohub-dimension-field">
                <input type="number" 
                       id="cargohub_height" 
                       name="cargohub_height" 
                       value="<?php echo esc_attr($height); ?>" 
                       step="0.1" 
                       min="0.1" 
                       required
                       class="cargohub-input-field" />
                <span class="cargohub-dimension-label"><?php esc_html_e('Height', 'cargohub'); ?></span>
            </div>
        </div>
        
        <p class="description">
            <?php esc_html_e('Enter the dimensions of your package.', 'cargohub'); ?>
        </p>
    </div>
</div>
<hr class="cargohub-separator" />