<?php
/**
 * Fired when the plugin is uninstalled.
 *
 * @since      1.0.0
 * @package    CargoHub
 */

// If uninstall is not called from WordPress, exit
if (!defined('WP_UNINSTALL_PLUGIN')) {
    exit;
}

// Define constants for uninstall process
define('CARGOHUB_REMOVE_TABLES', true); // Set to false to keep tables on uninstall
define('CARGOHUB_REMOVE_SETTINGS', true); // Set to false to keep settings on uninstall
define('CARGOHUB_REMOVE_ORDER_META', false); // Set to true to remove all order meta data (not recommended)

// Database tables to remove
$tables = array(
    'cargohub_rates',
    'cargohub_zones',
    'cargohub_service_types'
);

// Settings to remove
$options = array(
    'cargohub_general_settings',
    'cargohub_display_settings',
    'cargohub_activation_time'
);

// If removing tables is enabled
if (CARGOHUB_REMOVE_TABLES) {
    global $wpdb;
    
    foreach ($tables as $table) {
        $wpdb->query("DROP TABLE IF EXISTS {$wpdb->prefix}{$table}");
    }
}

// If removing settings is enabled
if (CARGOHUB_REMOVE_SETTINGS) {
    foreach ($options as $option) {
        delete_option($option);
    }
}

// If removing order meta is enabled (be careful with this!)
if (CARGOHUB_REMOVE_ORDER_META) {
    global $wpdb;
    
    // Remove all order meta data related to CargoHub
    $meta_keys = array(
        '_cargohub_weight',
        '_cargohub_volumetric_weight',
        '_cargohub_chargeable_weight',
        '_cargohub_length',
        '_cargohub_width',
        '_cargohub_height',
        '_cargohub_service_type',
        '_cargohub_cod_option',
        '_cargohub_shipping_cost',
        '_cargohub_cod_fee',
        '_cargohub_total_cost'
    );
    
    foreach ($meta_keys as $meta_key) {
        $wpdb->delete($wpdb->postmeta, array('meta_key' => $meta_key));
    }
}

// Clear any cached data that might be stored
wp_cache_flush();